/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.types;

import java.math.BigInteger;

/**
 * Logical grouping of memory-related properties of virtual machine-like entities.
 */
public interface MemoryPolicy {
    boolean ballooning();
    
    boolean ballooningPresent();
    
    BigInteger guaranteed();
    Byte guaranteedAsByte();
    Short guaranteedAsShort();
    Integer guaranteedAsInteger();
    Long guaranteedAsLong();
    
    boolean guaranteedPresent();
    
    BigInteger max();
    Byte maxAsByte();
    Short maxAsShort();
    Integer maxAsInteger();
    Long maxAsLong();
    
    boolean maxPresent();
    
    MemoryOverCommit overCommit();
    
    boolean overCommitPresent();
    
    TransparentHugePages transparentHugePages();
    
    boolean transparentHugePagesPresent();
    
}
